"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OnBeforeTrigger = void 0;
var _listIndexes = require("./listIndexes");
var _createIndex = require("./createIndex");
var _listCreateElasticsearchIndexTaskPlugin = require("./listCreateElasticsearchIndexTaskPlugin");
class OnBeforeTrigger {
  constructor(params) {
    this.context = params.context;
    this.indexManager = params.indexManager;
  }
  async run(targets) {
    const plugins = (0, _listCreateElasticsearchIndexTaskPlugin.listCreateElasticsearchIndexTaskPlugin)(this.context.plugins);
    const tenant = this.context.tenancy.getCurrentTenant();
    if (!tenant?.id) {
      throw new Error("Something went wrong, tenant not found when triggering a task.");
    }
    const locale = this.context.i18n.getContentLocale();
    if (!locale) {
      throw new Error("Something went wrong, locale not found when triggering a task.");
    }
    try {
      const allIndexes = await (0, _listIndexes.listIndexes)({
        context: this.context,
        plugins,
        tenants: [tenant],
        locales: [locale]
      });
      const indexes = allIndexes.filter(index => {
        if (!targets?.length) {
          return true;
        }
        for (const t of targets) {
          if (index.index.includes(t)) {
            return true;
          }
        }
        return false;
      });
      if (indexes.length === 0) {
        console.warn("There are no indexes to create before triggering the Create indexes task.", {
          targets
        });
        return;
      }
      const createIndex = (0, _createIndex.createIndexFactory)(this.indexManager);
      for (const {
        index,
        settings
      } of indexes) {
        try {
          console.log("Creating index", index);
          await createIndex.createIfNotExists(index, settings);
        } catch (ex) {
          console.error(`Failed to create index "${index}".`, ex);
        }
      }
    } catch (ex) {
      console.error(ex);
    }
  }
}
exports.OnBeforeTrigger = OnBeforeTrigger;

//# sourceMappingURL=OnBeforeTrigger.js.map